function bezierCurve(ctx, points, px, py, pw, ph) {
	var size = points.length;
	if (size > 0) {
		ctx.strokeStyle = "#FF0000";
		ctx.save();
		ctx.translate(px, py);
		ctx.scale(pw / boundingBoxSize, ph / boundingBoxSize);
		ctx.beginPath();
		for ( var i = 0; i < size; i++) {
			var p = points[i];
			if (i == 0) {
				ctx.moveTo(p.x, p.y);
			}

			var pP = points[(i + size - 1) % (size)];
			var nP = points[(i + 1) % (size)];

			var vec1 = {
					x : p.x + ((nP.x - pP.x) / 7),
					y : p.y + ((nP.y - pP.y) / 7)
			};

			var nnP = points[(i + 2) % (size)];
			var vec2 = {
					x : nP.x + ((p.x - nnP.x) / 7),
					y : nP.y + ((p.y - nnP.y) / 7)
			};

			ctx.bezierCurveTo(vec1.x, vec1.y, vec2.x, vec2.y, nP.x,
					nP.y);
		}
		ctx.fill();
		ctx.stroke();
		ctx.restore();
	}
}

function bezierCurve2(ctx, points, px, py) {
	var size = points.length;
	if (size > 0) {
		ctx.strokeStyle = "#FF0000";
		ctx.save();
		ctx.translate(px, py);
		//ctx.scale(pw / boundingBoxSize, ph / boundingBoxSize);
		ctx.beginPath();
		for ( var i = 0; i < size; i++) {
			var p = points[i];
			if (i == 0) {
				ctx.moveTo(p.x*physUnit, p.y*physUnit);
			}

			var pP = points[(i + size - 1) % (size)];
			var nP = points[(i + 1) % (size)];

			var vec1 = {
					x : p.x + ((nP.x - pP.x) / 7),
					y : p.y + ((nP.y - pP.y) / 7)
			};

			var nnP = points[(i + 2) % (size)];
			var vec2 = {
					x : nP.x + ((p.x - nnP.x) / 7),
					y : nP.y + ((p.y - nnP.y) / 7)
			};

			ctx.bezierCurveTo(vec1.x*physUnit, vec1.y*physUnit, vec2.x*physUnit, vec2.y*physUnit, nP.x*physUnit,
					nP.y*physUnit);
		}
		ctx.fill();
		ctx.stroke();
		ctx.restore();
	}
}

function drawImage(resId, ctx, x, y, w, h){
	var img = resourceArr[resId];
	var sx;
	var sy;
	var sw;
	var sh;
	if(img == undefined){
		var obj = assetsArr[resId]
		img = resourceArr[obj.src];
		sx = obj.x;
		sy = obj.y;
		sw = obj.w;
		sh = obj.h;
	}else{
		sx = 0;
		sy = 0;
		sw = img.width;
		sh = img.height;
	}

	ctx.drawImage(img, sx, sy, sw, sh, x, y, w, h);
}

function drawBlocks(ctx, jsonMap) {
	var entities = [];
	for(var lindex = -2;lindex < 6;lindex++){
		for ( var i in jsonMap.entities) {
			var entity = jsonMap.entities[i];
			if(entity.layer == lindex){
				entities.push(entity);
			}else{
				
			}
		}
	}


	ctx.clearRect ( 0, 0, screenWidth, screenHeight );
	ctx.save();
	ctx.translate(camera.x* physUnit,camera.y* physUnit);

	ctx.fillStyle = "#5CB3FF";
	ctx.fillRect(-camera.x* physUnit,-camera.y* physUnit, screenWidth, screenHeight);

	ctx.globalAlpha = 0.4;
	for(var i = 0; i < 10; i++){
		ctx.beginPath();  
		ctx.moveTo(i*worldSize/10,0);  
		ctx.lineTo(i*worldSize/10,worldSize);    
		ctx.closePath();  
		ctx.stroke(); 

		ctx.beginPath();  
		ctx.moveTo(0,i*worldSize/10);  
		ctx.lineTo(worldSize,i*worldSize/10);    
		ctx.closePath();  
		ctx.stroke();

	}



	for ( var i in entities) {
		ctx.fillStyle = "#fff";
		ctx.strokeStyle = "#000";
		ctx.globalAlpha = 1;
		var entity = entities[i];
		if(entity.image != undefined){
			if (entity.type == "tupsu") {
				/*alert("tupsu");
				ctx.beginPath();
				ctx.arc(entity.x * physUnit, entity.y * physUnit,
						(entity.w + entity.w) / 4 * physUnit, 0,
						Math.PI * 2, true);
				ctx.fill();
				ctx.stroke();
				*/
				ctx.save();
				ctx.translate((entity.x) * physUnit, (entity.y) * physUnit);
				ctx.rotate(entity.a);

				ctx.beginPath();
				ctx.arc(0, 0,
						(entity.w + entity.w) / 4 * physUnit, 0,
						Math.PI * 2, true);
				ctx.fill();
				ctx.stroke();
				ctx.restore()
				
			} else if (entity.type == "roundedStaticBlock") {
				ctx.fillStyle = (entity.property == 'neutral')?"#aaa":"#8f6";
				

				if (entity.points != undefined) {
					bezierCurve(ctx, entity.points,
							(entity.x - (entity.w / 2)) * physUnit,
							(entity.y - (entity.h / 2)) * physUnit,
							entity.w * physUnit, entity.h * physUnit);
					ctx.fillStyle = "#000";
					ctx.fillRect(entity.x * physUnit, entity.y * physUnit,
							10, 10);
				}
			} else if (entity.type == "roundedBlock" || entity.type == "backgroundBlock") {
				if(entity.property != undefined){
					ctx.fillStyle = (entity.property == 'neutral')?"#aaa":"#8f6";
					ctx.fillStyle = (entity.ice == true)?"#fff":ctx.fillStyle;
				}else{
					ctx.fillStyle = "#000";
				}
				

				if (entity.points != undefined) {
					bezierCurve2(ctx, entity.points,(entity.x) * physUnit, (entity.y) * physUnit);
					ctx.fillStyle = "#000";
					ctx.fillRect(entity.x * physUnit, entity.y * physUnit,
							10, 10);
				}
			}else if(entity.type == "pinnedBlock"){
				ctx.save();
				ctx.translate((entity.x) * physUnit, (entity.y) * physUnit);
				ctx.rotate(entity.a);

				
				drawImage(entity.image, ctx, (-entity.w / 2) * physUnit,
						(-entity.h / 2) * physUnit, entity.w * physUnit,
						entity.h * physUnit);
				drawImage(entity.pinImage, ctx, ((-1 / 2)+entity.px) * physUnit,
						(-1 / 2) * physUnit, 1 * physUnit,
						1 * physUnit);
				
				/*ctx.drawImage(img, sx, sy, sw, sh, (-entity.w / 2) * physUnit,
						(-entity.h / 2) * physUnit, entity.w * physUnit,
						entity.h * physUnit);

				ctx.drawImage(resourceArr[entity.pinImage], ((-1 / 2)+entity.px) * physUnit,
						(-1 / 2) * physUnit, 1 * physUnit,
						1 * physUnit);*/
				ctx.restore();
			} else {
				ctx.save();
				ctx.translate((entity.x) * physUnit, (entity.y) * physUnit);
				ctx.rotate(entity.a);

				drawImage(entity.image, ctx, (-entity.w / 2) * physUnit,
						(-entity.h / 2) * physUnit, entity.w * physUnit,
						entity.h * physUnit);
				/*ctx.drawImage(resourceArr[entity.image], (-entity.w / 2) * physUnit,
						(-entity.h / 2) * physUnit, entity.w * physUnit,
						entity.h * physUnit);*/

				ctx.restore();
			}
		}else{
			if (entity.type == "tupsu") {
				ctx.save();
				ctx.translate((entity.x) * physUnit, (entity.y) * physUnit);
				ctx.rotate(entity.a);

				ctx.beginPath();
				ctx.arc(0, 0,
						(entity.w + entity.w) / 4 * physUnit, 0,
						Math.PI * 2, true);
				ctx.fill();
				ctx.stroke();
				ctx.restore();
			}else{
				ctx.save();
				ctx.translate((entity.x) * physUnit, (entity.y) * physUnit);
				ctx.rotate(entity.a);

				ctx.fillRect((-entity.w / 2) * physUnit,
						(-entity.h / 2) * physUnit, entity.w * physUnit,
						entity.h * physUnit);

				ctx.restore();
			}
			
		}

		/*else if (entity.type == "BlockFinish") {
			ctx.fillStyle = "#0f0";
			ctx.arc(entity.x * physUnit, entity.y * physUnit,
					(entity.w + entity.w) / 4 * physUnit, 0,
					Math.PI * 2, true);
			ctx.fill();
			ctx.stroke();
		} else if (entity.type == "Food") {
			ctx.fillStyle = "#f00";
			ctx.arc(entity.x * physUnit, entity.y * physUnit,
					(entity.w + entity.w) / 4 * physUnit, 0,
					Math.PI * 2, true);
			ctx.fill();
			ctx.stroke();
		} *//*else {
			ctx.globalAlpha = 0.6;
			ctx.fillRect((entity.x - (entity.w / 2)) * physUnit,
					(entity.y - (entity.h / 2)) * physUnit, entity.w
		 * physUnit, entity.h * physUnit);
			ctx.strokeRect((entity.x - (entity.w / 2)) * physUnit,
					(entity.y - (entity.h / 2)) * physUnit, entity.w
		 * physUnit, entity.h * physUnit);
		}*/
	}

	ctx.fillStyle = "#f00";
	ctx.strokeStyle = "#000";
	ctx.globalAlpha = 1;
	if(jsonMap.camera != undefined){
		ctx.beginPath();
		ctx.arc(jsonMap.camera.x * physUnit, jsonMap.camera.y * physUnit,3, 0,Math.PI * 2, true);
		ctx.fill();
		ctx.stroke();
	}
	
	ctx.fillStyle = "#00f";
	if(jsonMap.hint != undefined){
		ctx.beginPath();
		ctx.arc(jsonMap.hint.x * physUnit, jsonMap.hint.y * physUnit,3, 0,Math.PI * 2, true);
		ctx.fill();
		ctx.stroke();
	}

	ctx.restore();


}

function drawVertexRect(ctx,x,y,w,h){
	ctx.fillStyle = "#fff";
	ctx.strokeStyle = "#000";
	ctx.fillRect(x, y, w, h);
	ctx.stroke();
}

function drawVertex(ctx, x, y, r){
	ctx.fillStyle = "#000";
	ctx.fillRect(x, y, r, r);
}
